==> roots-3.0.0-rc.9.tgz: package/readme.md <==
<p></p>
<p align="center"><a><img src="http://cl.ly/V7me/logo.svg" /></a></p>
<br />

<p align="center">
  <a title='NPM version' href="http://badge.fury.io/js/roots">
    <img src='http://img.shields.io/npm/v/roots.svg?style=flat' />
  </a>
  <a title='Build Status' href="https://travis-ci.org/jenius/roots">
    <img src='http://img.shields.io/travis/jenius/roots/v3.svg?style=flat' />
  </a>
  <a href='https://coveralls.io/r/jenius/roots?branch=v3'>
    <img src='http://img.shields.io/coveralls/jenius/roots/v3.svg?style=flat' alt='Coverage Status' />
  </a>
  <a title='Dependency Status' href="https://gemnasium.com/jenius/roots">
    <img src='http://img.shields.io/gemnasium/jenius/roots.svg?style=flat' />
  </a>
</p>

Roots is a fast, simple, and customizable static site compiler.

### Roots v3 Beta

Roots version 3 is currently in beta, so use at your own risk! You can find up-to-date docs for this version at http://roots.rtfd.org.

If you help us test the prerelease versions of roots v3, we will love you forever. You also get free exclusive premium VIP support from the roots core team, which you can get access to [here](https://gitter.im/jenius/roots).

### Why should you care?

If you make a lot of websites, or perhaps even make websites as a profession, there's no doubt that you will want to be very efficient at making websites, and on top of that you'll probably want to have the websites you make be very fast, cheap to host, and simple to build and optimize. If this is the case for you, my friend, you have come to the right place - roots is what you are looking for.

Roots is a tool for web developers to build static sites very quickly. Now, this doesn't mean that it's reserved only for websites without a server -- roots is also set up to be able to work very smoothly with client-side mv* frameworks like backbone or angular, and compliments them very well.

Roots is completely transparent, and is behind many large websites in production. It is sponsored heavily by [carrot creative](http://carrot.is), has been under active development for almost 2 years, and is very actively maintained and developed to this day. In short, you can rely on roots.

Roots is certainly not the only static site compiler out there. Check out a [comparison to other available static compilers](docs/features.rst).

### Installation

`npm install roots -g`

### Usage

See [the docs](http://roots.rtfd.org) for more info. As we get closer to release, this section will be expanded out to a basic 'getting started' tutorial and table of contents for the docs.

### License & Contributing

- Details on the license [can be found here](license.md)
- Details on running tests and contributing [can be found here](contributing.md)
- Details on how to get super rich from contributing to roots [can be found here](contributing.md#getting-money)

==> roots-4.0.1.tgz: package/readme.md <==
<p></p>
<p align="center"><a><img src="http://cl.ly/V7me/logo.svg" /></a></p>
<br />

<p align="center">
  <a title='NPM version' href="http://badge.fury.io/js/roots">
    <img src='http://img.shields.io/npm/v/roots.svg?style=flat' />
  </a>
  <a title='Build Status' href="https://travis-ci.org/jenius/roots">
    <img src='http://img.shields.io/travis/jenius/roots/v3.svg?style=flat' />
  </a>
  <a href='https://coveralls.io/r/jenius/roots?branch=v3'>
    <img src='http://img.shields.io/coveralls/jenius/roots/v3.svg?style=flat' alt='Coverage Status' />
  </a>
  <a title='Dependency Status' href="https://gemnasium.com/jenius/roots">
    <img src='http://img.shields.io/gemnasium/jenius/roots.svg?style=flat' />
  </a>
</p>

Roots is a fast, simple, and customizable static site compiler.

### Why should you care?

If you make a lot of websites, or perhaps even make websites as a profession, there's no doubt that you will want to be very efficient at making websites, and on top of that you'll probably want to have the websites you make be very fast, cheap to host, and simple to build and optimize. If this is the case for you, my friend, you have come to the right place - roots is what you are looking for.

Roots is a tool for web developers to build static sites very quickly. Now, this doesn't mean that it's reserved only for websites without a server -- roots is also set up to be able to work very smoothly with client-side mv* frameworks like backbone or angular, and compliments them very well.

Roots is completely transparent, and is behind many large websites in production. It is sponsored heavily by [carrot creative](http://carrot.is), has been under active development for almost 2 years, and is very actively maintained and developed to this day. In short, you can rely on roots.

Roots is certainly not the only static site compiler out there. But in our opinion, it's the most powerful and easiest to use. Give it a shot and see for yourself!

### Installation

`npm install roots -g` - if you get an `EACCES` error, [check here](http://roots.cx/docs/error#eacces-permission-denied)

### Usage

See [the docs](http://roots.cx/docs) for more info. You can also find a number of tutorial videos [here](http://roots.cx).

### Support

You can get support for and talk about roots in our [gitter chatroom](https://gitter.im/jenius/roots). Community, yay!

### License & Contributing

- Details on the license [can be found here](license.md)
- Details on running tests and contributing [can be found here](contributing.md)
- Details on how to get super rich from contributing to roots [can be found here](contributing.md#getting-money)
